(define-module (ui zabbix-server ajax)
    :use-module (alterator ajax)
    :use-module (alterator str)
    :use-module (alterator woo)
    :use-module (alterator effect)
    :export (init))

; DEBUG STRING (PASTE IN FOR YOUR NEEDS).
; (format #t "XXX: ~S\n" rdp_profile_name)
; (format #t "[ajax, module] action info\n")

; TO DEBUG DO:
; 1) define *debug* to #t
; 2) start ahttpd -l -d
(define *debug* #f)
(define (dmsg msg . args)
  (if *debug*
    (format #t "[ajax, zabbix-server]: ~S ~S\n" msg args)))

;(define *is_clamav* #f)

;(define (ui-read)
;  (let* ((data (woo-read "/postfix-dovecot"))
;;         (domain_master (woo-get-option (car data) 'domain_master)))
;    (set! *is_clamav* (woo-get-option (car data) 'is_installed_clamsmtpd))
;    (dmsg "Clamav software present flag:" *is_clamav*)
;    (dmsg "Domain master:" domain_master)
;    (form-update-value-list data)
;    (form-update-activity "can_use_clamav" *is_clamav*)
;;    (form-update-visibility "nodomain_page" (not domain_master))
;    (form-update-activity "apply_button"  domain_master)))


; PERFORM BASIC INITIALIZATION
(define (write-init)

  (dmsg "write-init() -- enter")

  (catch/message
    (lambda()
      (woo-write "/zabbix-server/init"
                 'mysql_admin_pass (form-value "mysql_admin_pass"))))
  (read-current-status))


; TURN OFF
(define (write-off)

  (dmsg "write-off() -- enter")

  (catch/message
    (lambda()
      (woo-write "/zabbix-server/off"
                 'language (form-value "language"))))
  (read-current-status))


; SAVE ZABBIX SERVER SETTINGS
(define (write-z-save)

  (dmsg "write-z-save() -- enter")

  (catch/message
    (lambda()
      (apply woo-write "/zabbix-server/zabbix"
             'language (form-value "language")
             (form-value-list))
      (read-current-status))))


; SET NEW ADMIN PASSWORD FOR WEB GUI
(define (write-z-save-new-admin-password)

  (dmsg "write-z-save-new-admin-password() -- enter")

  (catch/message
    (lambda()
      (woo-write "/zabbix-server/admin_password"
             'mysql_admin_pass2 (form-value "mysql_admin_pass2")
             'input_z_new_admin_password (form-value "input_z_new_admin_password")
             'language (form-value "language")
             )
      (read-current-status))))


; RESET ALL VALUES
(define (widgets-reset)

  (dmsg "Reset all widgets\n")

  (for-each (lambda(p) (form-update-value p ""))
            '("label_status_z_enabled"
              "label_status_z_info"
              "mysql_admin_pass2"
              "mysql_admin_pass"
              "input_z_new_admin_password"))
  (form-update-value "list_zabbix_mode" "off"))


; UPDATE WIDGETS STATUS
(define (widgets-update)

  (dmsg "Update widgets status\n")
  (form-update-activity "btn_serial_save" #f))


; READ CURRENT SETTINGS
(define (read-current-status)
  (dmsg "Read current status\n")

  (and

    ; RESET WIDGETS
    (widgets-reset)

    ; FILL LISTS
    (for-each
      (lambda(lst)
        (form-update-enum lst
                          (woo-list
                            (string-append "/zabbix-server/" lst)
                            'language (form-value "language"))))
      '("list_zabbix_mode"))

    ; REBIND ACTIONS ON LISTS
    ;;(form-bind "list_z_type" "change" serial-edit)

    ; READ CURRENT SETTINGS
    (let* ((settings
             (woo-read-first "/zabbix-server/status"
                             'language (form-value "language")))
           ; Fill
           (usb-hid (woo-get-option settings 'usb_hid #f))


           (mysql-local-is-configured (woo-get-option settings 'cfg_done #f))
           (mysql-local-pass-req (woo-get-option settings 'bool_mysql_pass_required #f))
           (serial-ctrl-on (woo-get-option settings 'serial_ctrl_on #f)))

      ; Fill widgets
      (form-update-value-list settings) 

      (form-update-value "label_serial_control" (if serial-ctrl-on (_ "Serial ports control activated" "alterator-ports-access") (_ "Serial ports control deactivated" "alterator-ports-access")))
      (form-update-value "bool_allow_hid" usb-hid)
      (form-update-visibility "area-mysql-local-settings" mysql-local-is-configured)
      (form-update-visibility "mysql-local-pass" mysql-local-pass-req)

      ; Configuration status
      (dmsg "Initial configuration is done:" mysql-local-is-configured)
      (form-update-visibility "area-mysql-local-initial-cfg" (not mysql-local-is-configured))
      (form-update-visibility "area-mysql-local" mysql-local-is-configured)
      )

    ; UPDATE WIDGETS STATUS
    (widgets-update)))


; INITIALIZATION ROUTINE
(define (init)

  (dmsg "init() -- enter")

  ; INTERCONNECT BUTTON WITH ACTION
  (form-bind "btn-do-init" "click" write-init)
  (form-bind "btn-off-save" "click" write-off)
  (form-bind "btn-z-save" "click" write-z-save)
  (form-bind "btn-z-save-new-admin-password" "click" write-z-save-new-admin-password)

  ;  (form-bind "bool_allow_hid" "change" allow-usb-hid)

  (effect-show "information" "chk_box_info" #t)
  (effect-show "area-mysql-local" "list_zabbix_mode" "zabbix_local_mysql") 
  (effect-show "area-off" "list_zabbix_mode" "off") 
  (init-effect)


  ; INTERFACE INITIALIZATION
  (read-current-status))

; vim: ft=lisp expandtab
